@@ -9,11 +9,7 @@ from authx.services import SearchService
 def get_router(repo: UsersRepo, admin_required: Callable):
 
     SearchService.setup(repo)
-    """
-    Search router
-
-    Returns:
-        APIRouter -- Search router
+    """Search router, for searching users
     """
 
     router = APIRouter()
