@@ -7,38 +7,19 @@ from authx.models.user import UserPrivateInfo
 
 
 class SearchService:
-    """
-    Private
-
-    Raises:
-        HTTPException: If the user does not exist.
-
-    Returns:
-        The user.
+    """Class Search Service is a Class that contains all the methods to search for users, and get a user by id.
+    Support Search by Page and Pagination for the users.
     """
 
     _repo: UsersRepo
 
     @classmethod
     def setup(cls, repo: UsersRepo) -> None:
-        """
-        Setup the service with the given repository.
-        """
+        """Setup the service with the given repository."""
         cls._repo = repo
 
     async def get_user(self, id: int):
-        """
-        Get a user by id.
-
-        Args:
-            id: The id of the user.
-
-        Raises:
-            HTTPException: If the user does not exist.
-
-        Returns:
-            The user.
-        """
+        """Get a user by id."""
         item = await self._repo.get(id)
         if item is None:
             raise HTTPException(404)
@@ -46,17 +27,7 @@ class SearchService:
         return UserPrivateInfo(**item).dict(by_alias=True)
 
     async def search(self, id: Optional[int], username: Optional[str], p: int) -> dict:
-        """
-        Search for users.
-
-            Args:
-                id: The id of the user.
-                username: The username of the user.
-                p: The page number.
-
-            Returns:
-                The users.
-            """
+        """Search for users."""
         PAGE_SIZE = 20
         items, count = await self._repo.search(id, username, p, PAGE_SIZE)
         div = count // PAGE_SIZE
